@@ -5,7 +5,7 @@ author = {
 	"email":"maloja@krateng.dev",
 	"github": "krateng"
 }
-version = 2,4,10
+version = 2,5,0
 versionstr = ".".join(str(n) for n in version)
 links = {
 	"pypi":"malojaserver",
@@ -15,7 +15,7 @@ links = {
 requires = [
 	"bottle>=0.12.16",
 	"waitress>=1.3",
-	"doreah>=1.5.6",
+	"doreah>=1.6.3",
 	"nimrodel>=0.6.3",
 	"setproctitle>=1.1.10",
 	"wand>=0.5.4",
@@ -33,5 +33,5 @@ resources = [
 ]
 
 commands = {
-	"maloja":"controller:main"
+	"maloja":"proccontrol.control:main"
 }
